@@ -57,8 +57,10 @@ class Grilo(GObject.GObject):
         Grl.METADATA_KEY_CREATION_DATE,
         Grl.METADATA_KEY_COMPOSER,
         Grl.METADATA_KEY_DURATION,
+        Grl.METADATA_KEY_FAVOURITE,
         Grl.METADATA_KEY_ID,
         Grl.METADATA_KEY_LYRICS,
+        Grl.METADATA_KEY_PLAY_COUNT,
         Grl.METADATA_KEY_THUMBNAIL,
         Grl.METADATA_KEY_TITLE,
         Grl.METADATA_KEY_TRACK_NUMBER,
@@ -290,14 +292,24 @@ class Grilo(GObject.GObject):
 
     @log
     def toggle_favorite(self, song_item):
-        # TODO: change "bool(song_item.get_lyrics())" --> song_item.get_favourite() once query works properly
-        # TODO: when .set/get_favourite work, set_favourite outside loop: item.set_favourite(!item.get_favourite())
-        if bool(song_item.get_lyrics()):  # is favorite
-            self.sparqltracker.update(Query.remove_favorite(song_item.get_url()), GLib.PRIORITY_DEFAULT, None)
+        """Toggles favorite status for media item
+
+        Toggles favorite status and writes it back to the tracker store
+        :param song_item: A Grilo media item
+        """
+        if song_item.get_favourite():
+            # For now keep unsetting the lyrics to deal with how
+            # previous versions dealt with favorites.
             song_item.set_lyrics("")
-        else:  # not favorite
-            self.sparqltracker.update(Query.add_favorite(song_item.get_url()), GLib.PRIORITY_DEFAULT, None)
-            song_item.set_lyrics("i'm truthy")
+            song_item.set_favourite(False)
+        else:
+            song_item.set_favourite(True)
+
+        # FIXME: We assume this is the tracker plugin.
+        # FIXME: Doing this async crashes
+        self.tracker.store_metadata_sync(song_item,
+                                         [Grl.METADATA_KEY_FAVOURITE],
+                                         Grl.WriteFlags.NORMAL)
 
     @log
     def set_favorite(self, song_item, favorite):
@@ -306,7 +318,7 @@ class Grilo(GObject.GObject):
         :param song_item: A Grilo media item
         :param bool favorite: Set favorite status
         """
-        if bool(song_item.get_lyrics()) != favorite:
+        if song_item.get_favourite() != favorite:
             self.toggle_favorite(song_item)
 
     @log
@@ -363,5 +375,72 @@ class Grilo(GObject.GObject):
 
         self.tracker.query(query, self.METADATA_KEYS, options, callback, None)
 
+    @log
+    def bump_play_count(self, media):
+        """Bumps the play count of a song
+
+        Adds one to the playcount and adds it to the tracker store
+        :param media: A Grilo media item
+        """
+        count = media.get_play_count()
+        media.set_play_count(count + 1)
+
+        # FIXME: We assume this is the tracker plugin.
+        # FIXME: Doing this async crashes
+        self.tracker.store_metadata_sync(media, [Grl.METADATA_KEY_PLAY_COUNT],
+                                         Grl.WriteFlags.NORMAL)
+
+    @log
+    def set_last_played(self, media):
+        """Sets the date-time when the media was last played
+
+        Sets the last played date-time for the media.
+        :param media: A Grilo media item
+        """
+        media.set_last_played(GLib.DateTime.new_now_utc())
+        # FIXME: We assume this is the tracker plugin.
+        # FIXME: Doing this async crashes
+        self.tracker.store_metadata_sync(media, [Grl.METADATA_KEY_LAST_PLAYED],
+                                         Grl.WriteFlags.NORMAL)
+
+    @log
+    def songs_available(self, callback):
+        """Checks if there are any songs available
+
+        Calls a callback function with True or False depending on the
+        availability of songs.
+        :param callback: Function to call on result
+        """
+        def cursor_next_cb(conn, res, data):
+            try:
+                has_next = conn.next_finish(res)
+            except GLib.Error as err:
+                logger.warn("Error: %s, %s", err.__class__, err)
+                callback(False)
+                return
+
+            if has_next:
+                count = conn.get_integer(0)
+
+                if count > 0:
+                    callback(True)
+                    return
+
+            callback(False)
+
+        def songs_query_cb(conn, res, data):
+            try:
+                cursor = conn.query_finish(res)
+            except GLib.Error as err:
+                logger.warn("Error: %s, %s", err.__class__, err)
+                callback(False)
+                return
+
+            cursor.next_async(None, cursor_next_cb, None)
+
+        # TODO: currently just checks tracker, should work with any
+        # queryable supported Grilo source.
+        self.sparqltracker.query_async(Query.all_songs_count(), None,
+                                       songs_query_cb, None)
 
 grilo = Grilo()
