@@ -148,7 +148,7 @@ class Playlists(GObject.GObject):
             """ Called after the playlist id is fetched """
             try:
                 cursor.next_finish(res)
-            except GLib.Error as error:
+            except GLib.Error as err:
                 logger.warn("Error: %s, %s", err.__class__, err)
                 return
 
@@ -165,7 +165,7 @@ class Playlists(GObject.GObject):
             """ Starts retrieving the playlist id """
             try:
                 cursor = obj.query_finish(result)
-            except GLib.Error as error:
+            except GLib.Error as err:
                 logger.warn("Error: %s, %s", err.__class__, err)
                 return
 
@@ -192,7 +192,7 @@ class Playlists(GObject.GObject):
             # Update the playlist ID
             try:
                 cursor.next_finish(res)
-            except GLib.Error as error:
+            except GLib.Error as err:
                 logger.warn("Error: %s, %s", err.__class__, err)
                 return
 
@@ -205,7 +205,7 @@ class Playlists(GObject.GObject):
             """ Called after the playlist is created and the ID is fetched """
             try:
                 cursor = obj.query_finish(res)
-            except GLib.Error as error:
+            except GLib.Error as err:
                 logger.warn("Error: %s, %s", err.__class__, err)
                 return
 
@@ -235,17 +235,6 @@ class Playlists(GObject.GObject):
                                         GLib.PRIORITY_LOW, None,
                                         tag_created_cb, playlist)
 
-    @log
-    def update_playcount(self, song_url):
-        query = Query.update_playcount(song_url)
-        self.tracker.update(query, GLib.PRIORITY_LOW, None)
-
-    @log
-    def update_last_played(self, song_url):
-        cur_time = time.strftime(sparql_dateTime_format, time.gmtime())
-        query = Query.update_last_played(song_url, cur_time)
-        self.tracker.update(query, GLib.PRIORITY_LOW, None)
-
     @log
     def update_static_playlist(self, playlist):
         """Given a static playlist (subclass of StaticPlaylists), updates according to its query."""
@@ -315,7 +304,7 @@ class Playlists(GObject.GObject):
 
         def cursor_callback(cursor, res, data):
             try:
-                has_next = cursor.next_finish()
+                has_next = cursor.next_finish(res)
             except GLib.Error as err:
                 logger.warn("Error: %s, %s", err.__class__, err)
                 return
